Crate wasmtime_cli_flags

Crate wasmtime_cli_flags 

A utility crate for managing Wasmtime configuration options in a serializable format.

This crate primarily provides a CommonOptions structure which can be parsed from CLI flags via [clap] or with [serde::Deserialize]. This structure can additionally be created from a wasmtime::Engine to serialize some of the significant configuration options affecting an engine.

This is intended to be a shared way for embedders to configure Wasmtime with serializable configuration. The source of truth for Wasmtime’s configuration is the Config type but this additionally serves as a means of creating that type.

Modules

opt
Support for parsing Wasmtime’s -O, -W, etc “option groups”

Macros

wasmtime_option_group

Structs

CodegenOptions
CommonOptions
Common options for commands that translate WebAssembly modules
DebugOptions
KeyValuePair
OptimizeOptions
RecordOptions
WasiNnGraph
WasiOptions
WasmOptions