pub struct CompileTimeBuiltin {
pub name: String,
pub path: PathBuf,
}Expand description
A compile-time builtin.
Fields
name: StringThe instance import name that this satisfies in the main component.
path: PathBufThe path to the component that implements this builtin.