pub struct CommonOptions {
pub opts: OptimizeOptions,
pub codegen: CodegenOptions,
pub debug: DebugOptions,
pub wasm: WasmOptions,
pub wasi: WasiOptions,
pub record: RecordOptions,
pub target: Option<String>,
pub config: Option<PathBuf>,
/* private fields */
}Expand description
Common options for commands that translate WebAssembly modules
Fields
opts: OptimizeOptionscodegen: CodegenOptionsdebug: DebugOptionswasm: WasmOptionswasi: WasiOptionsrecord: RecordOptionstarget: Option<String>The target triple; default is the host triple
config: Option<PathBuf>Use the specified TOML configuration file.
This TOML configuration file can provide same configuration options as the
--optimize, --codegen, --debug, --wasm, --wasi CLI options, with a couple exceptions.
Additional options specified on the command line will take precedent over options loaded from this TOML file.
Implementations
Sourceimpl CommonOptions
impl CommonOptions
Sourcepub fn new() -> CommonOptions
pub fn new() -> CommonOptions
Creates a blank new set of CommonOptions that can be configured.
pub fn init_logging(&mut self) -> Result<()>
pub fn config( &mut self, pooling_allocator_default: Option<bool>, ) -> Result<Config>
pub fn enable_wasm_features(&self, config: &mut Config) -> Result<()>
Sourcepub fn from_engine(engine: &Engine) -> Self
pub fn from_engine(engine: &Engine) -> Self
Creates an instance of CommonOptions by reflecting on the
configuration present in the provided Engine.
This will extract all configuration values that can be set by this
CommonOptions into a Config into the returned structure to the
best of its ability. Not all configuration options present on Engine
can be reflected back into CommonOptions, and not all options on
CommonOptions can be set on an Engine. This means that this
is a lossy operation that doesn’t fully capture 100% of the
configuration of Engine. That being said, however, it can capture
almost all of the configuration related to codegen and major other
configuration options.